<?php

namespace Drupal\custom_configuration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\custom_configuration\Helper\ConfigurationHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Form\drupal_set_message;

/**
 * Class Configuration Setting.
 *
 * @package Drupal\custom_configuration\Form
 */
class ConfigurationSetting extends ConfigFormBase {

  protected $configHelpler;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigurationHelper $configHelper) {
    $this->configHelpler = $configHelper;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
        $container->get('custom.configuration')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('custom.configuration');
    $form['custom_configuration'] = [
      '#type' => 'detail',
      '#title' => $this->t('Custom Configuration'),
      '#open' => TRUE,
    ];
    $form['custom_configuration']['add_configuration'] = [
      '#type' => 'detail',
      '#title' => $this->t('Add Configuration'),
    ];
    $form['custom_configuration']['add_configuration']['key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Key name'),
      '#maxlength' => 50,
      '#required' => TRUE,
      '#default_value' => $config->get('key') ? $config->get('key') : '',
    ];
    $form['custom_configuration']['add_configuration']['value'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Value'),
      '#required' => TRUE,
      '#rows' => 10,
      '#cols' => 58,
      '#attributes' => ['style' => 'width:auto'],
      '#default_value' => $config->get('value') ? $config->get('key') : '',
    ];
    $form['custom_configuration']['add_configuration']['status'] = [
      '#type' => 'select',
      '#title' => $this->t('Configuration Status'),
      '#options' => [
        '0' => $this->t('Inactive'),
        '1' => $this->t('Active'),
      ],
      '#default_value' => $config->get('key') ? $config->get('key') : 1,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'custom_configuration';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $post = [
      'name' => $form_state->getValue('key'),
      'config_value' => $form_state->getValue('value'),
      'status' => $form_state->getValue('status'),
    ];
    $return = $this->configHelpler->createConfiguration($post);
    drupal_set_message($this->t("@message", ['@message' => $return['message']]), $return['status']);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['custom.configuration'];
  }

}
