<?php

namespace Drupal\custom_configuration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\custom_configuration\Helper\ConfigurationHelper;
use Drupal\Core\Link;

/**
 * Class CustomConfigurationList.
 *
 * @package Drupal\custom_configuration\Form
 */
class CustomConfigurationList extends ConfigFormBase {

  protected $configHelpler;

  /**
   * Construct of the Custom Configuration List.
   *
   * @param \Drupal\custom_configuration\Form\ConfigurationHelper $configHelper
   *   This will create an object of the ConfigurationHelper class.
   */
  public function __construct(ConfigurationHelper $configHelper) {
    $this->configHelpler = $configHelper;
  }

  /**
   * This will help us to achieve the dependency injection.
   *
   * @param Symfony\Component\DependencyInjection\ContainerInterface $container
   *   It will get all the services inside the container interface.
   *
   * @return \static
   *   It will return the service of the class.
   */
  public static function create(ContainerInterface $container) {
    return new static(
        $container->get('custom.configuration')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['custom_configuration.listShow'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'custom_configuration_list';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['config-list'] = [
      '#type' => 'table',
      '#header' => [$this->t('Config Name'), $this->t('Machine Name'), $this->t(
            'Value'
        ), $this->t('Config Status'), $this->t('Updated Date'),
        $this->t('Edit'),
        $this->t('Delete'),
      ],
      '#empty' => 'There are no items yet. Add a Custom Configuration.',
    ];
    $result_list = $this->configHelpler->getConfigList();
    foreach ($result_list as $list) {
      $form['config-list'][$list->custom_config_id]['config_name'] = [
        '#markup' => $list->custom_config_name,
      ];
      $form['config-list'][$list->custom_config_id]['machine_name'] = [
        '#markup' => $list->custom_config_machine_name,
      ];
      $form['config-list'][$list->custom_config_id]['custom_config_value'] = [
        '#markup' => $list->custom_config_value,
      ];
      $form['config-list'][$list->custom_config_id]['custom_config_status'] = [
        '#markup' => ($list->custom_config_status == 1) ? 'ACTIVE' : 'INACTIVE',
      ];

      $form['config-list'][$list->custom_config_id]['custom_config_updated_date'] = [
        '#markup' => date('d-M-Y H:i', $list->custom_config_updated_date),
      ];
      $edit_link = Link::createFromRoute(
              $this->t('Edit'), 'custom_configuration.edit_configuration_list', ['custom_config_id' => $list->custom_config_id]
          )->toString();
      $form['config-list'][$list->custom_config_id]['edit'] = [
        '#markup' => $edit_link,
      ];
      $delete_link = Link::createFromRoute($this->t('Delete'), 'custom_configuration.delete_configuration_list', ['custom_config_id' => $list->custom_config_id])->toString();
      $form['config-list'][$list->custom_config_id]['delete'] = [
        '#markup' => $delete_link,
      ];
    }
    return $form;
  }

}
